﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ConsoleGame
{
    class Game
    {
        public bool IsRunning { get; private set; }

        private Player player;
        private Hospital hospital;

        public static List<String> Log = new List<string>();

        public Game()
        {
            IsRunning = true;
            player = new Player("Honza");
            hospital = new Hospital();
        }

        public void Draw()
        {
            Console.Clear();
            player.Draw();
            hospital.Draw();
            Console.WriteLine();
            DrawHelp();
            // draw log, few newest entries
            Console.WriteLine();
            var lastMsgs = Log.AsEnumerable().Reverse().Take(10);
            foreach (string message in lastMsgs)
            {
                Console.WriteLine(message);
            }
        }

        private void DrawHelp()
        {
            Console.WriteLine("Controls:");
            Console.WriteLine("ESC: exit, ARROWS: move, A: attack bandit");
            Console.WriteLine("F1: enter hospital, F2: exit hospital, F3: upgrade hospital");
        }

        public void Update()
        {
            player.Update();
            if (!player.IsAlive())
            {
                Game.Log.Add("Byl jste zabit.");
                IsRunning = false;
            }
        }

        public void OnKeyPressed(ConsoleKeyInfo keyInfo)
        {
            switch (keyInfo.Key)
            {
                case ConsoleKey.F1:
                    {
                        player.EnterHospital(hospital);
                    }
                    break;

                case ConsoleKey.F2:
                    {
                        player.ExitHospital();
                    }
                    break;

                case ConsoleKey.F3:
                    {
                        hospital.Upgrade(player);
                    }
                    break;

                case ConsoleKey.LeftArrow:
                    {
                        player.MoveLeft();
                    }
                    break;

                case ConsoleKey.A:
                    {
                        player.AttackBandit();
                    }
                    break;

                case ConsoleKey.RightArrow:
                    {
                        player.MoveRight();
                    }
                    break;

                case ConsoleKey.UpArrow:
                    {
                        player.MoveUp();
                    }
                    break;

                case ConsoleKey.DownArrow:
                    {
                        player.MoveDown();
                    }
                    break;

                case ConsoleKey.Escape:
                    {
                        IsRunning = false;
                    }
                    break;
            }
        }
    }
}
