﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ConsoleGame
{
    class Player
    {
        private int x;
        private int y;
        private string name;
        private int gold;
        private int life;
        private int maxLife;

        private DateTime lastMove = DateTime.Now;
        private Hospital hospital;

        private Random r = new Random();

        public void EnterHospital(Hospital hospital) 
        {
            if (!IsInHospital())
            {
                this.hospital = hospital;
                Game.Log.Add(String.Format("{0} entered hospital.", name));
            }
        }

        public void ExitHospital()
        {
            if (IsInHospital())
            {
                this.hospital = null;
                Game.Log.Add(String.Format("{0} exited hospital.", name));
            }
        }

        public Player(string name)
        {
            this.name = name;
            life = 25;
            maxLife = 50;
            gold = 100;
            x = 10;
            y = 10;
        }

        public string GetName()
        {
            return name;
        }

        public void MoveLeft()
        {
            if (canMove())
                x--;
        }

        public void MoveRight()
        {
            if (canMove())
                x++;
        }

        public void MoveUp()
        {
            if (canMove())
                y--;
        }

        public void MoveDown()
        {
            if (canMove())
                y++;
        }

        private bool canMove()
        {
            if ((DateTime.Now - lastMove).TotalMilliseconds > 1000)
            {
                lastMove = DateTime.Now;
                return true;
            }
            return false;
        }

        public void Heal(int amount)
        {
            if (life < maxLife)
            {
                life += amount;
            }

            if (life > maxLife)
                life = maxLife;
        }

        public void Attacked(int amount)
        {
            life -= amount;
        }

        public void AttackBandit()
        {
            if (!IsInHospital())
            {
                int health = r.Next(11);
                int gold = r.Next(6);
                Game.Log.Add(String.Format("Player {0} attacked bandit, gained {1} gold and lost {2} health.", name, gold, health));
                Attacked(health);
                PickUpGold(gold);
            }
            else
                Game.Log.Add("Can not attack bandits from hospital.");

        }

        public bool IsInjured()
        {
            return life < maxLife;
        }

        public bool IsAlive()
        {
            return life > 0;
        }

        public bool IsInHospital()
        {
            return hospital != null;
        }

        public void PickUpGold(int amount)
        {
            gold += amount;
        }

        public bool WithdrawGold(int amount)
        {
            if (gold >= amount)
            {
                gold -= amount;
                return true;
            }

            return false;
        }

        public void Update()
        {
            if (hospital != null)
                hospital.Update(this);
        }

        public void Draw()
        {
            Console.WriteLine(name);
            Console.WriteLine("Life: {0}/{1}", life, maxLife);
            Console.WriteLine("Gold: {0}", gold);
            Console.WriteLine("Pozice: {0}, {1}, InHospital: {2}", x, y, hospital!=null);
        }
    }
}
